@@ -9,14 +9,26 @@ use serde::{Deserialize, Serialize};
 #[derive(Serialize, Deserialize, Debug)]
 pub struct AddIndex {
     pub table: String,
+    pub index: Index,
+}
+
+#[derive(Serialize, Deserialize, Clone, Debug)]
+pub struct Index {
     pub name: String,
     pub columns: Vec<String>,
+    #[serde(default)]
+    pub unique: bool,
+    #[serde(rename = "type")]
+    pub index_type: Option<String>,
 }
 
 #[typetag::serde(name = "add_index")]
 impl Action for AddIndex {
     fn describe(&self) -> String {
-        format!("Adding index \"{}\" to table \"{}\"", self.name, self.table)
+        format!(
+            "Adding index \"{}\" to table \"{}\"",
+            self.index.name, self.table
+        )
     }
 
     fn run(
@@ -30,15 +42,22 @@ impl Action for AddIndex {
         let column_real_names: Vec<String> = table
             .columns
             .iter()
-            .filter(|column| self.columns.contains(&column.name))
-            .map(|column| column.real_name.to_string())
+            .filter(|column| self.index.columns.contains(&column.name))
+            .map(|column| format!("\"{}\"", column.real_name))
             .collect();
 
+        let unique = if self.index.unique { "UNIQUE" } else { "" };
+        let index_type_def = if let Some(index_type) = &self.index.index_type {
+            format!("USING {index_type}")
+        } else {
+            "".to_string()
+        };
+
         db.run(&format!(
-            "
-			CREATE INDEX CONCURRENTLY {name} ON {table} ({columns})
-			",
-            name = self.name,
+            r#"
+			CREATE {unique} INDEX CONCURRENTLY "{name}" ON "{table}" {index_type_def} ({columns}) 
+			"#,
+            name = self.index.name,
             table = self.table,
             columns = column_real_names.join(", "),
         ))
@@ -58,10 +77,10 @@ impl Action for AddIndex {
 
     fn abort(&self, _ctx: &MigrationContext, db: &mut dyn Conn) -> anyhow::Result<()> {
         db.run(&format!(
-            "
-			DROP INDEX CONCURRENTLY IF EXISTS {name}
-			",
-            name = self.name,
+            r#"
+			DROP INDEX CONCURRENTLY IF EXISTS "{name}"
+			"#,
+            name = self.index.name,
         ))
         .context("failed to drop index")?;
         Ok(())
